@@ -11,7 +11,6 @@
 # under the License.
 
 import eventlet
-import six
 
 from oslo_context import context as oslo_context
 from oslo_log import log as logging
@@ -21,7 +20,7 @@ from senlin.common.i18n import _
 from senlin.drivers import base
 from senlin.drivers.os import neutron_v2 as neutronclient
 from senlin.drivers.os import octavia_v2 as octaviaclient
-from senlin.engine import node as nodem
+from senlin.profiles import base as pb
 
 LOG = logging.getLogger(__name__)
 
@@ -62,8 +61,7 @@ class LoadBalancerDriver(base.DriverBase):
         """Keep waiting until loadbalancer is ready
 
         This method will keep waiting until loadbalancer resource specified
-        by lb_id becomes ready, i.e. its provisioning_status is ACTIVE and
-        its operating_status is ONLINE.
+        by lb_id becomes ready, i.e. its provisioning_status is ACTIVE.
 
         :param lb_id: ID of the load-balancer to check.
         :param ignore_not_found: if set to True, nonexistent loadbalancer
@@ -79,9 +77,7 @@ class LoadBalancerDriver(base.DriverBase):
             if lb is None:
                 lb_ready = ignore_not_found
             else:
-                lb_ready = ((lb.provisioning_status == 'ACTIVE') and
-                            (lb.operating_status == 'ONLINE'))
-
+                lb_ready = lb.provisioning_status == 'ACTIVE'
             if lb_ready is True:
                 return True
 
@@ -93,7 +89,7 @@ class LoadBalancerDriver(base.DriverBase):
 
         return False
 
-    def lb_create(self, vip, pool, hm=None):
+    def lb_create(self, vip, pool, hm=None, az=None, flavor_id=None):
         """Create a LBaaS instance
 
         :param vip: A dict containing the properties for the VIP;
@@ -107,20 +103,27 @@ class LoadBalancerDriver(base.DriverBase):
 
         result = {}
         # Create loadblancer
+        subnet_id = None
+        network_id = None
         try:
-            subnet = self.nc().subnet_get(vip['subnet'])
+            if vip.get('subnet'):
+                subnet = self.nc().subnet_get(vip['subnet'])
+                subnet_id = subnet.id
+            if vip.get('network'):
+                network = self.nc().network_get(vip['network'])
+                network_id = network.id
         except exception.InternalError as ex:
             msg = 'Failed in getting subnet: %s.' % ex
             LOG.exception(msg)
             return False, msg
-        subnet_id = subnet.id
         try:
-            lb = self.oc().loadbalancer_create(subnet_id,
-                                               vip.get('address', None),
-                                               vip['admin_state_up'])
+            lb = self.oc().loadbalancer_create(
+                subnet_id, network_id, vip.get('address', None),
+                vip['admin_state_up'], availability_zone=az,
+                flavor_id=flavor_id)
         except exception.InternalError as ex:
             msg = ('Failed in creating loadbalancer: %s.'
-                   % six.text_type(ex))
+                   % str(ex))
             LOG.exception(msg)
             return False, msg
         result['loadbalancer'] = lb.id
@@ -141,7 +144,7 @@ class LoadBalancerDriver(base.DriverBase):
                                                          None),
                                                  vip['admin_state_up'])
         except exception.InternalError as ex:
-            msg = 'Failed in creating lb listener: %s.' % six.text_type(ex)
+            msg = 'Failed in creating lb listener: %s.' % str(ex)
             LOG.exception(msg)
             return False, msg
         result['listener'] = listener.id
@@ -156,9 +159,10 @@ class LoadBalancerDriver(base.DriverBase):
         try:
             pool = self.oc().pool_create(pool['lb_method'], listener.id,
                                          pool['protocol'],
+                                         pool['session_persistence'],
                                          pool['admin_state_up'])
         except exception.InternalError as ex:
-            msg = 'Failed in creating lb pool: %s.' % six.text_type(ex)
+            msg = 'Failed in creating lb pool: %s.' % str(ex)
             LOG.exception(msg)
             return False, msg
         result['pool'] = pool.id
@@ -180,7 +184,7 @@ class LoadBalancerDriver(base.DriverBase):
                 hm['url_path'], hm['expected_codes'])
         except exception.InternalError as ex:
             msg = ('Failed in creating lb health monitor: %s.'
-                   % six.text_type(ex))
+                   % str(ex))
             LOG.exception(msg)
             return False, msg
         result['healthmonitor'] = health_monitor.id
@@ -217,7 +221,7 @@ class LoadBalancerDriver(base.DriverBase):
                 self.oc().healthmonitor_delete(healthmonitor_id)
             except exception.InternalError as ex:
                 msg = ('Failed in deleting healthmonitor: %s.'
-                       % six.text_type(ex))
+                       % str(ex))
                 LOG.exception(msg)
                 return False, msg
             res = self._wait_for_lb_ready(lb_id)
@@ -232,7 +236,7 @@ class LoadBalancerDriver(base.DriverBase):
                 self.oc().pool_delete(pool_id)
             except exception.InternalError as ex:
                 msg = ('Failed in deleting lb pool: %s.'
-                       % six.text_type(ex))
+                       % str(ex))
                 LOG.exception(msg)
                 return False, msg
             res = self._wait_for_lb_ready(lb_id)
@@ -246,7 +250,7 @@ class LoadBalancerDriver(base.DriverBase):
                 self.oc().listener_delete(listener_id)
             except exception.InternalError as ex:
                 msg = ('Failed in deleting listener: %s.'
-                       % six.text_type(ex))
+                       % str(ex))
                 LOG.exception(msg)
                 return False, msg
             res = self._wait_for_lb_ready(lb_id)
@@ -284,9 +288,12 @@ class LoadBalancerDriver(base.DriverBase):
         net_name = net.name
 
         ctx = oslo_context.get_current()
-        node_obj = nodem.Node.load(ctx, db_node=node)
-        node_detail = node_obj.get_details(ctx)
+        prof = pb.Profile.load(ctx,
+                               profile_id=node.profile_id,
+                               project_safe=False)
+        node_detail = prof.do_get_details(node)
         addresses = node_detail.get('addresses')
+        node_name = node_detail.get('name')
         if net_name not in addresses:
             LOG.error('Node is not in subnet %(subnet)s', {'subnet': subnet})
             return None
@@ -314,8 +321,8 @@ class LoadBalancerDriver(base.DriverBase):
             if not res:
                 msg = 'Loadbalancer %s is not ready.' % lb_id
                 raise exception.Error(msg)
-            member = self.oc().pool_member_create(pool_id, address, port,
-                                                  subnet_obj.id)
+            member = self.oc().pool_member_create(
+                node_name, pool_id, address, port, subnet_obj.id)
         except (exception.InternalError, exception.Error) as ex:
             LOG.exception('Failed in creating lb pool member: %s.', ex)
             return None
@@ -342,10 +349,11 @@ class LoadBalancerDriver(base.DriverBase):
             # loadbalancer status will be checked before deleting lb member
             # request is sent out. If loadbalancer keeps unready till waiting
             # timeout, exception will be raised to fail member_remove.
-            res = self._wait_for_lb_ready(lb_id)
-            if not res:
-                msg = 'Loadbalancer %s is not ready.' % lb_id
-                raise exception.Error(msg)
+            res = self._wait_for_lb_ready(lb_id, ignore_not_found=True)
+            # res = self._wait_for_lb_ready(lb_id)
+            # if not res:
+            #     msg = 'Loadbalancer %s is not ready.' % lb_id
+            #     raise exception.Error(msg)
             self.oc().pool_member_delete(pool_id, member_id)
         except (exception.InternalError, exception.Error) as ex:
             LOG.exception('Failed in removing member %(m)s from pool %(p)s: '
