@@ -37,7 +37,8 @@ class OctaviaClient(base.DriverBase):
     @sdk.translate_exception
     def loadbalancer_create(self, vip_subnet_id=None, vip_network_id=None,
                             vip_address=None, admin_state_up=True, name=None,
-                            description=None, availability_zone=None):
+                            description=None, availability_zone=None,
+                            flavor_id=None):
 
         kwargs = {
             'admin_state_up': admin_state_up,
@@ -55,6 +56,8 @@ class OctaviaClient(base.DriverBase):
             kwargs['description'] = description
         if availability_zone is not None:
             kwargs['availability_zone'] = availability_zone
+        if flavor_id is not None:
+            kwargs['flavor_id'] = flavor_id
 
         res = self.conn.load_balancer.create_load_balancer(**kwargs)
         return res
@@ -95,12 +98,18 @@ class OctaviaClient(base.DriverBase):
 
     @sdk.translate_exception
     def pool_create(self, lb_algorithm, listener_id, protocol,
-                    admin_state_up=True, name=None, description=None):
+                    session_persistence, admin_state_up=True,
+                    name=None, description=None):
+
+        # Remove cookie_name when type not equal to APP_COOKIE
+        if session_persistence['type'] != 'APP_COOKIE':
+            session_persistence.pop('cookie_name', None)
 
         kwargs = {
             'lb_algorithm': lb_algorithm,
             'listener_id': listener_id,
             'protocol': protocol,
+            'session_persistence': session_persistence,
             'admin_state_up': admin_state_up,
         }
 
@@ -119,10 +128,11 @@ class OctaviaClient(base.DriverBase):
         return
 
     @sdk.translate_exception
-    def pool_member_create(self, pool_id, address, protocol_port, subnet_id,
-                           weight=None, admin_state_up=True):
+    def pool_member_create(self, name, pool_id, address, protocol_port,
+                           subnet_id, weight=None, admin_state_up=True):
 
         kwargs = {
+            'name': name,
             'address': address,
             'protocol_port': protocol_port,
             'admin_state_up': admin_state_up,
@@ -172,3 +182,9 @@ class OctaviaClient(base.DriverBase):
         self.conn.load_balancer.delete_health_monitor(
             hm_id, ignore_missing=ignore_missing)
         return
+
+    @sdk.translate_exception
+    def find_flavor(self, flavor_id, ignore_missing=False):
+        self.conn.load_balancer.find_flavor(
+            flavor_id, ignore_missing=ignore_missing)
+        return
