@@ -29,7 +29,7 @@ LOG = logging.getLogger(__name__)
 class HealthPolicy(base.Policy):
     """Policy for health management of a cluster."""
 
-    VERSION = '1.1'
+    VERSION = '1.2'
     VERSIONS = {
         '1.0': [
             {'status': consts.EXPERIMENTAL, 'since': '2017.02'},
@@ -38,6 +38,9 @@ class HealthPolicy(base.Policy):
         '1.1': [
             {'status': consts.SUPPORTED, 'since': '2018.09'}
         ],
+        '1.2': [
+            {'status': consts.SUPPORTED, 'since': '2020.09'}
+        ],
     }
     PRIORITY = 600
 
@@ -46,10 +49,16 @@ class HealthPolicy(base.Policy):
         ('BEFORE', consts.CLUSTER_DEL_NODES),
         ('BEFORE', consts.CLUSTER_SCALE_IN),
         ('BEFORE', consts.CLUSTER_RESIZE),
+        ('BEFORE', consts.CLUSTER_UPDATE),
+        ('BEFORE', consts.CLUSTER_RECOVER),
+        ('BEFORE', consts.CLUSTER_REPLACE_NODES),
         ('BEFORE', consts.NODE_DELETE),
         ('AFTER', consts.CLUSTER_DEL_NODES),
         ('AFTER', consts.CLUSTER_SCALE_IN),
         ('AFTER', consts.CLUSTER_RESIZE),
+        ('AFTER', consts.CLUSTER_UPDATE),
+        ('AFTER', consts.CLUSTER_RECOVER),
+        ('AFTER', consts.CLUSTER_REPLACE_NODES),
         ('AFTER', consts.NODE_DELETE),
     ]
 
@@ -107,7 +116,7 @@ class HealthPolicy(base.Policy):
                 DETECTION_INTERVAL: schema.Integer(
                     _("Number of seconds between pollings. Only "
                       "required when type is 'NODE_STATUS_POLLING' or "
-                      "'NODE_STATUS_POLL_URL'."),
+                      "'NODE_STATUS_POLL_URL' or 'HYPERVISOR_STATUS_POLLING."),
                     default=60,
                 ),
                 NODE_UPDATE_TIMEOUT: schema.Integer(
@@ -316,7 +325,8 @@ class HealthPolicy(base.Policy):
 
         # check valid detection types
         polling_types = [consts.NODE_STATUS_POLLING,
-                         consts.NODE_STATUS_POLL_URL]
+                         consts.NODE_STATUS_POLL_URL,
+                         consts.HYPERVISOR_STATUS_POLLING]
 
         has_valid_polling_types = all(
             d.type in polling_types
@@ -410,9 +420,10 @@ class HealthPolicy(base.Policy):
     def pre_op(self, cluster_id, action, **args):
         """Hook before action execution.
 
-        One of the task for this routine is to disable health policy if the
-        action is a request that will shrink the cluster. The reason is that
-        the policy may attempt to recover nodes that are to be deleted.
+        Disable health policy for actions that modify cluster nodes (e.g.
+        scale in, delete nodes, cluster update, cluster recover and cluster
+        replace nodes).
+        For all other actions, set the health policy data in the action data.
 
         :param cluster_id: The ID of the target cluster.
         :param action: The action to be examined.
@@ -421,7 +432,10 @@ class HealthPolicy(base.Policy):
         """
         if action.action in (consts.CLUSTER_SCALE_IN,
                              consts.CLUSTER_DEL_NODES,
-                             consts.NODE_DELETE):
+                             consts.NODE_DELETE,
+                             consts.CLUSTER_UPDATE,
+                             consts.CLUSTER_RECOVER,
+                             consts.CLUSTER_REPLACE_NODES):
             health_manager.disable(cluster_id)
             return True
 
@@ -467,7 +481,10 @@ class HealthPolicy(base.Policy):
         """
         if action.action in (consts.CLUSTER_SCALE_IN,
                              consts.CLUSTER_DEL_NODES,
-                             consts.NODE_DELETE):
+                             consts.NODE_DELETE,
+                             consts.CLUSTER_UPDATE,
+                             consts.CLUSTER_RECOVER,
+                             consts.CLUSTER_REPLACE_NODES):
             health_manager.enable(cluster_id)
             return True
 
