@@ -42,7 +42,7 @@ class LoadBalancingPolicy(base.Policy):
     the cluster (which could be created by the policy) when these actions are
     performed.
     """
-    VERSION = '1.1'
+    VERSION = '1.3'
     VERSIONS = {
         '1.0': [
             {'status': consts.SUPPORTED, 'since': '2016.04'}
@@ -50,6 +50,12 @@ class LoadBalancingPolicy(base.Policy):
         '1.1': [
             {'status': consts.SUPPORTED, 'since': '2018.01'}
         ],
+        '1.2': [
+            {'status': consts.SUPPORTED, 'since': '2020.02'}
+        ],
+        '1.3': [
+            {'status': consts.SUPPORTED, 'since': '2020.03'}
+        ],
     }
 
     PRIORITY = 500
@@ -73,9 +79,11 @@ class LoadBalancingPolicy(base.Policy):
     ]
 
     KEYS = (
-        POOL, VIP, HEALTH_MONITOR, LB_STATUS_TIMEOUT, LOADBALANCER
+        POOL, VIP, HEALTH_MONITOR, LB_STATUS_TIMEOUT, LOADBALANCER,
+        AVAILABILITY_ZONE, FLAVOR_ID,
     ) = (
-        'pool', 'vip', 'health_monitor', 'lb_status_timeout', 'loadbalancer'
+        'pool', 'vip', 'health_monitor', 'lb_status_timeout', 'loadbalancer',
+        'availability_zone', 'flavor_id',
     )
 
     _POOL_KEYS = (
@@ -111,10 +119,10 @@ class LoadBalancingPolicy(base.Policy):
     )
 
     _VIP_KEYS = (
-        VIP_SUBNET, VIP_ADDRESS, VIP_CONNECTION_LIMIT, VIP_PROTOCOL,
-        VIP_PROTOCOL_PORT, VIP_ADMIN_STATE_UP,
+        VIP_SUBNET, VIP_NETWORK, VIP_ADDRESS, VIP_CONNECTION_LIMIT,
+        VIP_PROTOCOL, VIP_PROTOCOL_PORT, VIP_ADMIN_STATE_UP,
     ) = (
-        'subnet', 'address', 'connection_limit', 'protocol',
+        'subnet', 'network', 'address', 'connection_limit', 'protocol',
         'protocol_port', 'admin_state_up',
     )
 
@@ -196,8 +204,13 @@ class LoadBalancingPolicy(base.Policy):
             schema={
                 VIP_SUBNET: schema.String(
                     _('Name or ID of Subnet on which the VIP address will be '
-                      'allocated.'),
-                    required=True,
+                      'allocated. One of Subnet or Network is required.'),
+                    required=False,
+                ),
+                VIP_NETWORK: schema.String(
+                    _('Name or ID of Network on which the VIP address will be '
+                      'allocated. One of Subnet or Network is required.'),
+                    required=False,
                 ),
                 VIP_ADDRESS: schema.String(
                     _('IP address of the VIP.'),
@@ -283,6 +296,16 @@ class LoadBalancingPolicy(base.Policy):
             _('Name or ID of loadbalancer for the cluster on which nodes can '
               'be connected.'),
             default=None,
+        ),
+        AVAILABILITY_ZONE: schema.String(
+            _('Name of the loadbalancer availability zone to use for creation '
+              'of the loadbalancer.'),
+            default=None,
+        ),
+        FLAVOR_ID: schema.String(
+            _('ID of octavia loadbalancer flavor to use for creation '
+              'of the loadbalancer.'),
+            default=None,
         )
     }
 
@@ -292,6 +315,8 @@ class LoadBalancingPolicy(base.Policy):
         self.pool_spec = self.properties.get(self.POOL, {})
         self.vip_spec = self.properties.get(self.VIP, {})
         self.hm_spec = self.properties.get(self.HEALTH_MONITOR, None)
+        self.az_spec = self.properties.get(self.AVAILABILITY_ZONE, None)
+        self.flavor_id_spec = self.properties.get(self.FLAVOR_ID, None)
         self.lb_status_timeout = self.properties.get(self.LB_STATUS_TIMEOUT)
         self.lb = self.properties.get(self.LOADBALANCER, None)
 
@@ -313,13 +338,43 @@ class LoadBalancingPolicy(base.Policy):
                     ) % {'key': self.POOL_SUBNET, 'value': name_or_id}
             raise exc.InvalidSpec(message=msg)
 
-        # validate VIP subnet
-        name_or_id = self.vip_spec.get(self.VIP_SUBNET)
+        # validate loadbalancer flavor_id
+        flavor_id = self.flavor_id_spec
+        if flavor_id:
+            try:
+                oc.find_flavor(flavor_id)
+            except exc.InternalError:
+                msg = _("The specified %(key)s '%(value)s' could not be found."
+                        ) % {'key': self.FLAVOR_ID, 'value': flavor_id}
+                raise exc.InvalidSpec(message=msg)
+
+        # validate VIP subnet or network
+        subnet_name_or_id = self.vip_spec.get(self.VIP_SUBNET)
+        network_name_or_id = self.vip_spec.get(self.VIP_NETWORK)
+        if not subnet_name_or_id and not network_name_or_id:
+            msg = _("At least one of VIP Subnet or Network must be defined.")
+            raise exc.InvalidSpec(message=msg)
         try:
-            nc.subnet_get(name_or_id)
+            # Check subnet if it is set
+            obj_type = self.VIP_SUBNET
+            name_or_id = subnet_name_or_id
+            if name_or_id:
+                nc.subnet_get(name_or_id)
+
+            # Check network if it is set
+            obj_type = self.VIP_NETWORK
+            name_or_id = network_name_or_id
+            if name_or_id:
+                nc.network_get(name_or_id)
+
+            # TODO(rm_work): We *could* do more validation here to catch issues
+            # at validation time, like verifying the subnet's network_id is the
+            # same as the id of the network, if both are set -- but for now we
+            # will just leave that up to the LB API, which means if there is a
+            # failure, it won't be caught until attach time.
         except exc.InternalError:
             msg = _("The specified %(key)s '%(value)s' could not be found."
-                    ) % {'key': self.VIP_SUBNET, 'value': name_or_id}
+                    ) % {'key': obj_type, 'value': name_or_id}
             raise exc.InvalidSpec(message=msg)
 
         # validate loadbalancer
@@ -359,7 +414,8 @@ class LoadBalancingPolicy(base.Policy):
                 data['healthmonitor'] = self.hm_spec.get(self.HM_ID)
         else:
             res, data = lb_driver.lb_create(self.vip_spec, self.pool_spec,
-                                            self.hm_spec)
+                                            self.hm_spec, self.az_spec,
+                                            self.flavor_id_spec)
             if res is False:
                 return False, data
 
