@@ -18,12 +18,11 @@ import fixtures
 from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_serialization import jsonutils
-import six
 import testscenarios
 import testtools
 
 from senlin.common import messaging
-from senlin.engine import scheduler
+from senlin.engine import service
 from senlin.tests.unit.common import utils
 
 
@@ -63,13 +62,13 @@ class SenlinTestCase(testscenarios.WithScenarios,
     def setUp(self):
         super(SenlinTestCase, self).setUp()
         self.setup_logging()
-        scheduler.ENABLE_SLEEP = False
+        service.ENABLE_SLEEP = False
         self.useFixture(fixtures.MonkeyPatch(
             'senlin.common.exception._FATAL_EXCEPTION_FORMAT_ERRORS',
             True))
 
         def enable_sleep():
-            scheduler.ENABLE_SLEEP = True
+            service.ENABLE_SLEEP = True
 
         self.addCleanup(enable_sleep)
         self.addCleanup(cfg.CONF.reset)
@@ -88,8 +87,8 @@ class SenlinTestCase(testscenarios.WithScenarios,
             self._wallclock += self.TIME_STEP
             return self._wallclock
 
-        self.m.StubOutWithMock(scheduler, 'wallclock')
-        scheduler.wallclock = fake_wallclock
+        self.m.StubOutWithMock(service, 'wallclock')
+        service.wallclock = fake_wallclock
 
     def patchobject(self, obj, attr, **kwargs):
         mockfixture = self.useFixture(fixtures.MockPatchObject(obj, attr,
@@ -107,9 +106,9 @@ class SenlinTestCase(testscenarios.WithScenarios,
 
         This code is from Nova.
         """
-        if isinstance(expected, six.string_types):
+        if isinstance(expected, str):
             expected = jsonutils.loads(expected)
-        if isinstance(observed, six.string_types):
+        if isinstance(observed, str):
             observed = jsonutils.loads(observed)
 
         def sort_key(x):
