@@ -10,7 +10,8 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import mock
+from unittest import mock
+
 from oslo_messaging.rpc import dispatcher as rpc
 
 from senlin.common import consts
